@@ -1,7 +1,7 @@
 """
 Type annotations for rds-data service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/literals/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rds_data/literals/)
 
 Usage::
 
@@ -251,6 +251,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
